API Reference
=============

spreads.plugin
--------------

.. automodule:: spreads.plugin
   :members:
   :private-members:
   :inherited-members:
   :member-order: bysource

spreads.util
------------
.. automodule:: spreads.util
   :members:
   :member-order: bysource
